# sangarak
Python module for collecting distributed matrices from files and creating a single matrix.

# Usage

Method list:

* `read_matrix` - Read the matrix by specifying process IDs and file names.
* `read_file` - Read the matrix with lesser arguments by just specifying the file name.

# Installation

cd into the directory and run `pip install .`.

# Testing

cd into the root directory of the project and run `python setup.py test`.
